@@ -346,20 +346,26 @@ class DR_Results(OrderedDict):
 
         Example usage::
 
-           # merge "liftoff" and "meco" results and rename the
-           # liftoff results from "LO" to "Liftoff":
+            # merge "liftoff" and "meco" results and rename the
+            # liftoff results from "LO" to "Liftoff":
 
-           from pyyeti import cla
-           results = cla.DR_Results()
-           results.merge(
-               (cla.load(fn) for fn in ['../liftoff/results.pgz',
-                                        '../meco/results.pgz']),
-               {'LO': 'Liftoff'}
-               )
-           results.strip_hists()
-           results.form_extreme()
-           results['extreme'].rpttab()
-           cla.save('results.pgz', results)
+            from pyyeti import cla
+
+            results = cla.DR_Results()
+            results.merge(
+                (
+                    cla.load(fn)
+                    for fn in [
+                        "../liftoff/results.pgz",
+                        "../meco/results.pgz",
+                    ]
+                ),
+                {"LO": "Liftoff"},
+            )
+            results.strip_hists()
+            results.form_extreme()
+            results["extreme"].rpttab()
+            cla.save("results.pgz", results)
         """
 
         def _get_event_name(results):
@@ -374,20 +380,20 @@ class DR_Results(OrderedDict):
                     return ", ".join(key for key in results)
                 else:
                     return next(iter(v2.values())).event
-            raise TypeError(f"unexpected type: {str(type(results))}")
+            raise TypeError(f"unexpected type: {type(results)}")
 
         events = []
         for results in results_iter:
             event = _get_event_name(results)
             if rename_dict is not None:
-                try:
-                    newname = rename_dict[event]
-                except KeyError:
-                    pass
-                else:
-                    event = newname
-            events.append(event)
-            self[event] = results
+                event = rename_dict.get(event, event)
+
+            if event in self.keys():
+                raise ValueError(f"Event with name {event} already exists! Aborting.")
+            else:
+                events.append(event)
+                self[event] = results
+
         return events
 
     def split(self):
@@ -1000,9 +1006,9 @@ class DR_Results(OrderedDict):
         forcepsd,
         t_frc,
         freq,
-        incrb=2,
         verbose=False,
         allow_force_trimming=False,
+        **kwargs,
     ):
         """
         Solve equations of motion in frequency domain with PSD forces
@@ -1031,8 +1037,9 @@ class DR_Results(OrderedDict):
             of all combined :class:`DR_Def` objects with all ULVS
             matrices applied.
         fs : class instance
-            An instance of :class:`SolveUnc` or :class:`FreqDirect`
-            (or similar ... must have `.fsolve` method)
+            An instance of :class:`pyyeti.ode.SolveUnc` or
+            :class:`pyyeti.ode.FreqDirect` (or similar ... must have
+            ``.fsolve`` method)
         forcepsd : 2d array_like
             Matrix of force psds; each row is a force
         t_frc : 2d array_like
@@ -1049,18 +1056,6 @@ class DR_Results(OrderedDict):
             `forcepsd`: ``t_frc.shape[1] == forcepsd.shape[0]``
         freq : 1d array_like
             Frequency vector at which solution will be computed
-        incrb : 0, 1, or 2; optional
-            An input to the :func:`fs.fsolve` method, it specifies how
-            to handle rigid-body responses:
-
-            ======  ===============================================
-            incrb   description
-            ======  ===============================================
-               0    no rigid-body is included
-               1    acceleration and velocity rigid-body only
-               2    all of rigid-body is included (see `fs.fsolve`)
-            ======  ===============================================
-
         verbose : bool; optional
             If True, print status messages and timer results.
         allow_force_trimming : bool; optional
@@ -1070,6 +1065,18 @@ class DR_Results(OrderedDict):
             ("drmf"), the default is False. It is advisable to trim
             off zero forces before calling this routine and trim the
             corresponding columns off any "drmf" matrices.
+        **kwargs : keyword arguments for ``fs.fsolve``; optional
+            Currently, there are two arguments available:
+
+            ============  ============================================
+              argument    brief description
+            ============  ============================================
+            incrb         specifies how to handle rigid-body responses
+            rf_disp_only  specifies how to handle residual-flexibility
+                          modes
+            ============  ============================================
+
+            See, for example, :func:`pyyeti.ode.SolveUnc.fsolve`.
 
         Notes
         -----
@@ -1098,7 +1105,7 @@ class DR_Results(OrderedDict):
                 # solve for unit frequency response function for i'th
                 # force:
                 genforce = t_frc[:, [i]] @ unitforce;
-                sol = fs.fsolve(genforce, freq, incrb)
+                sol = fs.fsolve(genforce, freq, **kwargs)
                 sol.pg[:] = 0.0
                 sol.pg[i] = unitforce
                 sol = DR.frf_apply_uf(sol, nas["nrb"])
@@ -1179,7 +1186,7 @@ class DR_Results(OrderedDict):
             # solve for unit FRF for i'th force:
             genforce = t_frc[:, [i]] * unitforce
             t1 = time.time()
-            sol = fs.fsolve(genforce, freq, incrb)
+            sol = fs.fsolve(genforce, freq, **kwargs)
 
             # zeroing line not needed on first loop, but is okay (last
             # row gets re-zeroed)
